@@ -11,6 +11,13 @@ ALL_ROUTES = [
 
     ('call-api', 'SoftLayer.CLI.call_api:cli'),
 
+    ('account', 'SoftLayer.CLI.account'),
+    ('account:invoice-detail', 'SoftLayer.CLI.account.invoice_detail:cli'),
+    ('account:invoices', 'SoftLayer.CLI.account.invoices:cli'),
+    ('account:events', 'SoftLayer.CLI.account.events:cli'),
+    ('account:event-detail', 'SoftLayer.CLI.account.event_detail:cli'),
+    ('account:summary', 'SoftLayer.CLI.account.summary:cli'),
+
     ('virtual', 'SoftLayer.CLI.virt'),
     ('virtual:cancel', 'SoftLayer.CLI.virt.cancel:cli'),
     ('virtual:capture', 'SoftLayer.CLI.virt.capture:cli'),
@@ -29,8 +36,10 @@ ALL_ROUTES = [
     ('virtual:reboot', 'SoftLayer.CLI.virt.power:reboot'),
     ('virtual:reload', 'SoftLayer.CLI.virt.reload:cli'),
     ('virtual:upgrade', 'SoftLayer.CLI.virt.upgrade:cli'),
+    ('virtual:usage', 'SoftLayer.CLI.virt.usage:cli'),
     ('virtual:credentials', 'SoftLayer.CLI.virt.credentials:cli'),
     ('virtual:capacity', 'SoftLayer.CLI.virt.capacity:cli'),
+    ('virtual:placementgroup', 'SoftLayer.CLI.virt.placementgroup:cli'),
 
     ('dedicatedhost', 'SoftLayer.CLI.dedicatedhost'),
     ('dedicatedhost:list', 'SoftLayer.CLI.dedicatedhost.list:cli'),
@@ -75,15 +84,13 @@ ALL_ROUTES = [
     ('block:replica-failover', 'SoftLayer.CLI.block.replication.failover:cli'),
     ('block:replica-order', 'SoftLayer.CLI.block.replication.order:cli'),
     ('block:replica-partners', 'SoftLayer.CLI.block.replication.partners:cli'),
-    ('block:replica-locations',
-     'SoftLayer.CLI.block.replication.locations:cli'),
+    ('block:replica-locations', 'SoftLayer.CLI.block.replication.locations:cli'),
     ('block:snapshot-cancel', 'SoftLayer.CLI.block.snapshot.cancel:cli'),
     ('block:snapshot-create', 'SoftLayer.CLI.block.snapshot.create:cli'),
     ('block:snapshot-delete', 'SoftLayer.CLI.block.snapshot.delete:cli'),
     ('block:snapshot-disable', 'SoftLayer.CLI.block.snapshot.disable:cli'),
     ('block:snapshot-enable', 'SoftLayer.CLI.block.snapshot.enable:cli'),
-    ('block:snapshot-schedule-list',
-     'SoftLayer.CLI.block.snapshot.schedule_list:cli'),
+    ('block:snapshot-schedule-list', 'SoftLayer.CLI.block.snapshot.schedule_list:cli'),
     ('block:snapshot-list', 'SoftLayer.CLI.block.snapshot.list:cli'),
     ('block:snapshot-order', 'SoftLayer.CLI.block.snapshot.order:cli'),
     ('block:snapshot-restore', 'SoftLayer.CLI.block.snapshot.restore:cli'),
@@ -96,6 +103,10 @@ ALL_ROUTES = [
     ('block:volume-order', 'SoftLayer.CLI.block.order:cli'),
     ('block:volume-set-lun-id', 'SoftLayer.CLI.block.lun:cli'),
 
+    ('event-log', 'SoftLayer.CLI.event_log'),
+    ('event-log:get', 'SoftLayer.CLI.event_log.get:cli'),
+    ('event-log:types', 'SoftLayer.CLI.event_log.types:cli'),
+
     ('file', 'SoftLayer.CLI.file'),
     ('file:access-authorize', 'SoftLayer.CLI.file.access.authorize:cli'),
     ('file:access-list', 'SoftLayer.CLI.file.access.list:cli'),
@@ -110,8 +121,7 @@ ALL_ROUTES = [
     ('file:snapshot-delete', 'SoftLayer.CLI.file.snapshot.delete:cli'),
     ('file:snapshot-disable', 'SoftLayer.CLI.file.snapshot.disable:cli'),
     ('file:snapshot-enable', 'SoftLayer.CLI.file.snapshot.enable:cli'),
-    ('file:snapshot-schedule-list',
-     'SoftLayer.CLI.file.snapshot.schedule_list:cli'),
+    ('file:snapshot-schedule-list', 'SoftLayer.CLI.file.snapshot.schedule_list:cli'),
     ('file:snapshot-list', 'SoftLayer.CLI.file.snapshot.list:cli'),
     ('file:snapshot-order', 'SoftLayer.CLI.file.snapshot.order:cli'),
     ('file:snapshot-restore', 'SoftLayer.CLI.file.snapshot.restore:cli'),
@@ -152,10 +162,8 @@ ALL_ROUTES = [
     ('ipsec:subnet-add', 'SoftLayer.CLI.vpn.ipsec.subnet.add:cli'),
     ('ipsec:subnet-remove', 'SoftLayer.CLI.vpn.ipsec.subnet.remove:cli'),
     ('ipsec:translation-add', 'SoftLayer.CLI.vpn.ipsec.translation.add:cli'),
-    ('ipsec:translation-remove',
-     'SoftLayer.CLI.vpn.ipsec.translation.remove:cli'),
-    ('ipsec:translation-update',
-     'SoftLayer.CLI.vpn.ipsec.translation.update:cli'),
+    ('ipsec:translation-remove', 'SoftLayer.CLI.vpn.ipsec.translation.remove:cli'),
+    ('ipsec:translation-update', 'SoftLayer.CLI.vpn.ipsec.translation.update:cli'),
     ('ipsec:update', 'SoftLayer.CLI.vpn.ipsec.update:cli'),
 
     ('loadbal', 'SoftLayer.CLI.loadbal'),
@@ -176,25 +184,6 @@ ALL_ROUTES = [
     ('loadbal:service-edit', 'SoftLayer.CLI.loadbal.service_edit:cli'),
     ('loadbal:service-toggle', 'SoftLayer.CLI.loadbal.service_toggle:cli'),
 
-    ('messaging', 'SoftLayer.CLI.mq'),
-    ('messaging:accounts-list', 'SoftLayer.CLI.mq.accounts_list:cli'),
-    ('messaging:endpoints-list', 'SoftLayer.CLI.mq.endpoints_list:cli'),
-    ('messaging:ping', 'SoftLayer.CLI.mq.ping:cli'),
-    ('messaging:queue-add', 'SoftLayer.CLI.mq.queue_add:cli'),
-    ('messaging:queue-detail', 'SoftLayer.CLI.mq.queue_detail:cli'),
-    ('messaging:queue-edit', 'SoftLayer.CLI.mq.queue_edit:cli'),
-    ('messaging:queue-list', 'SoftLayer.CLI.mq.queue_list:cli'),
-    ('messaging:queue-pop', 'SoftLayer.CLI.mq.queue_pop:cli'),
-    ('messaging:queue-push', 'SoftLayer.CLI.mq.queue_push:cli'),
-    ('messaging:queue-remove', 'SoftLayer.CLI.mq.queue_remove:cli'),
-    ('messaging:topic-add', 'SoftLayer.CLI.mq.topic_add:cli'),
-    ('messaging:topic-detail', 'SoftLayer.CLI.mq.topic_detail:cli'),
-    ('messaging:topic-list', 'SoftLayer.CLI.mq.topic_list:cli'),
-    ('messaging:topic-push', 'SoftLayer.CLI.mq.topic_push:cli'),
-    ('messaging:topic-remove', 'SoftLayer.CLI.mq.topic_remove:cli'),
-    ('messaging:topic-subscribe', 'SoftLayer.CLI.mq.topic_subscribe:cli'),
-    ('messaging:topic-unsubscribe', 'SoftLayer.CLI.mq.topic_unsubscribe:cli'),
-
     ('metadata', 'SoftLayer.CLI.metadata:cli'),
 
     ('nas', 'SoftLayer.CLI.nas'),
@@ -202,10 +191,10 @@ ALL_ROUTES = [
     ('nas:credentials', 'SoftLayer.CLI.nas.credentials:cli'),
 
     ('object-storage', 'SoftLayer.CLI.object_storage'),
-    ('object-storage:accounts',
-     'SoftLayer.CLI.object_storage.list_accounts:cli'),
-    ('object-storage:endpoints',
-     'SoftLayer.CLI.object_storage.list_endpoints:cli'),
+
+    ('object-storage:accounts', 'SoftLayer.CLI.object_storage.list_accounts:cli'),
+    ('object-storage:endpoints', 'SoftLayer.CLI.object_storage.list_endpoints:cli'),
+    ('object-storage:credential', 'SoftLayer.CLI.object_storage.credential:cli'),
 
     ('order', 'SoftLayer.CLI.order'),
     ('order:category-list', 'SoftLayer.CLI.order.category_list:cli'),
@@ -215,6 +204,9 @@ ALL_ROUTES = [
     ('order:preset-list', 'SoftLayer.CLI.order.preset_list:cli'),
     ('order:package-locations', 'SoftLayer.CLI.order.package_locations:cli'),
     ('order:place-quote', 'SoftLayer.CLI.order.place_quote:cli'),
+    ('order:quote-list', 'SoftLayer.CLI.order.quote_list:cli'),
+    ('order:quote-detail', 'SoftLayer.CLI.order.quote_detail:cli'),
+    ('order:quote', 'SoftLayer.CLI.order.quote:cli'),
 
     ('rwhois', 'SoftLayer.CLI.rwhois'),
     ('rwhois:edit', 'SoftLayer.CLI.rwhois.edit:cli'),
@@ -235,8 +227,10 @@ ALL_ROUTES = [
     ('hardware:reload', 'SoftLayer.CLI.hardware.reload:cli'),
     ('hardware:credentials', 'SoftLayer.CLI.hardware.credentials:cli'),
     ('hardware:update-firmware', 'SoftLayer.CLI.hardware.update_firmware:cli'),
+    ('hardware:reflash-firmware', 'SoftLayer.CLI.hardware.reflash_firmware:cli'),
     ('hardware:rescue', 'SoftLayer.CLI.hardware.power:rescue'),
     ('hardware:ready', 'SoftLayer.CLI.hardware.ready:cli'),
+    ('hardware:toggle-ipmi', 'SoftLayer.CLI.hardware.toggle_ipmi:cli'),
 
     ('securitygroup', 'SoftLayer.CLI.securitygroup'),
     ('securitygroup:list', 'SoftLayer.CLI.securitygroup.list:cli'),
@@ -254,6 +248,7 @@ ALL_ROUTES = [
      'SoftLayer.CLI.securitygroup.interface:add'),
     ('securitygroup:interface-remove',
      'SoftLayer.CLI.securitygroup.interface:remove'),
+    ('securitygroup:event-log', 'SoftLayer.CLI.securitygroup.event_log:get_by_request_id'),
 
     ('sshkey', 'SoftLayer.CLI.sshkey'),
     ('sshkey:add', 'SoftLayer.CLI.sshkey.add:cli'),
@@ -316,4 +311,5 @@ ALL_ALIASES = {
     'vm': 'virtual',
     'vs': 'virtual',
     'dh': 'dedicatedhost',
+    'pg': 'placementgroup',
 }
